@@ -185,7 +185,7 @@ class AstToGrpcAst:
     '''
 
     def __init__(self, modelMessage: MessageInfo):
-        self.messages = []
+        self.messages : list[ProtoMessage] = []
         has_void = False
 
         # 1. create message of the model
